summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorruki <[email protected]>2023-08-21 23:48:02 +0800
committerruki <[email protected]>2023-08-21 23:48:02 +0800
commit2dd4262bd17ce4559608189c5cfa8ba90f729304 (patch)
tree01e8ab80234a2478a500a11308a3c16bc7d57fac
parent9abdbc065e073bc8a6e094be753755a3cead9add (diff)
rename function
-rw-r--r--xmake/plugins/project/vstudio/impl/vs201x_vcxproj.lua6
1 files changed, 3 insertions, 3 deletions
diff --git a/xmake/plugins/project/vstudio/impl/vs201x_vcxproj.lua b/xmake/plugins/project/vstudio/impl/vs201x_vcxproj.lua
index 2d1d35f63..f5bb88d73 100644
--- a/xmake/plugins/project/vstudio/impl/vs201x_vcxproj.lua
+++ b/xmake/plugins/project/vstudio/impl/vs201x_vcxproj.lua
@@ -1067,7 +1067,7 @@ function _make_common_items(vcxprojfile, vsinfo, target)
end
-- make header file
-function _make_header_file(vcxprojfile, includefile, vcxprojdir)
+function _make_include_file(vcxprojfile, includefile, vcxprojdir)
vcxprojfile:print("<ClInclude Include=\"%s\" />", path.relative(path.absolute(includefile), vcxprojdir))
end
@@ -1343,13 +1343,13 @@ function _make_source_files(vcxprojfile, vsinfo, target)
vcxprojfile:leave("</ItemGroup>")
- -- add header files
+ -- add include files
local pcheader = target.pcxxheader or target.pcheader
vcxprojfile:enter("<ItemGroup>")
for _, includefile in ipairs(table.join(target.headerfiles or {}, target.extrafiles)) do
-- we need to ignore pcheader file to fix https://github.com/xmake-io/xmake/issues/1171
if not pcheader or includefile ~= pcheader then
- _make_header_file(vcxprojfile, includefile, target.project_dir)
+ _make_include_file(vcxprojfile, includefile, target.project_dir)
end
end
vcxprojfile:leave("</ItemGroup>")